@@ -81,12 +81,12 @@ Fcbc=QMbc/QME
 Fcabc=QMabc/QME
 Fcad=QMad/QME
 
-pv.fs=c(1-pf(Fca,gla,glE), 1-pf(Fcb,glb,glE), 1-pf(Fcb,glb,glE))
+pv.fs=c(1-pf(Fca,gla,glE), 1-pf(Fcb,glb,glE), 1-pf(Fcc,glc,glE))
 
 #Montando a tabela da ANAVA
 an<-data.frame("DF"=c(gla, glb, glc, glab, glac, glbc, glabc, glad, glE, glT ),
 "SS"=c(round(c(SQa,SQb,SQc,SQab,SQac,SQbc,SQabc,SQad,SQE,SQT),5)),
-"MS"=c(round(c(QMa,QMb,QMc,QMab,QMac,QMbc,QMabc,QMad,QME,QMT),5)),
+"MS"=c(round(c(QMa,QMb,QMc,QMab,QMac,QMbc,QMabc,QMad,QME),5),''),
 "Fc"=c(round(c(Fca,Fcb,Fcc,Fcab,Fcac,Fcbc,Fcabc,Fcad),4),'',''),
 "Pr>Fc"=c(round(c(pv.fs, 1-pf(Fcab,glab,glE), 1-pf(Fcac,glac,glE), 1-pf(Fcbc,glbc,glE), 1-pf(Fcabc,glabc,glE), 1-pf(Fcad,glad,glE)),4), ' ', ' '))
 colnames(an)[5]="Pr>Fc"
@@ -95,8 +95,11 @@ paste(fac.names[2],'*',fac.names[3],sep=''),paste(fac.names[1],'*',fac.names[2],
 cat('------------------------------------------------------------------------
 Analysis of Variance Table\n------------------------------------------------------------------------\n')
 print(an)
-cat('------------------------------------------------------------------------\n\n')
+cat('------------------------------------------------------------------------\n')
 pvalor<-c(1-pf(Fca,gla,glE), 1-pf(Fcb,glb,glE), 1-pf(Fcc,glc,glE), 1-pf(Fcab,glab,glE), 1-pf(Fcac,glac,glE), 1-pf(Fcbc,glbc,glE), 1-pf(Fcabc,glabc,glE))
+#CV
+cv<-round(sqrt(as.numeric(an[9,3]))/mean(col3)*100, 2)
+cat('CV =',cv,'%\n')
 
 #Teste de normalidade
 pvalor.shapiro<-shapiro.test(anava$residuals)$p.value
@@ -131,13 +134,13 @@ cat('------------------------------------------------------------------------\n'
 
 #Para nenhuma interacao significativa, fazer...
 if(1-pf(Fcab,glab,glE)>sigF && 1-pf(Fcac,glac,glE)>sigF && 1-pf(Fcbc,glbc,glE)>sigF && 1-pf(Fcabc,glabc,glE)>sigF) {
-cat('\nNot significant interaction: analyzing the simple effect
+cat('\nNo significant interaction: analyzing the simple effect
 ------------------------------------------------------------------------\n')
 fatores<-data.frame('fator 1'=factor1,'fator 2' = factor2,'fator 3' = factor3)
 
 for(i in 1:3){
 #Para os fatores QUALITATIVOS, teste de Tukey
-if(quali[i]==TRUE && an[i,5]<=sigF) {
+if(quali[i]==TRUE && pvalor[i]<=sigF) {
     cat(fac.names[i])
       if(mcomp=='tukey'){
     tukey(resp,fatores[,i],an[9,1],an[9,2],sigT)
@@ -160,10 +163,14 @@ if(quali[i]==TRUE && an[i,5]<=sigF) {
   if(mcomp=='ccboot'){
     ccboot(resp,fatores[,i],an[9,1],an[9,2],sigT)
                     }
+  if(mcomp=='ccf'){
+    ccf(resp,fatores[,i],an[9,1],an[9,2],sigT)
+                    }
                    }
-if(quali[i]==TRUE && an[i,5]>sigF) {
+if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
 mean.table<-tapply.stat(resp,fatores[,i],mean)
 colnames(mean.table)<-c('Levels','Means')
 print(mean.table)
@@ -171,14 +178,15 @@ cat('------------------------------------------------------------------------')
 }
 
 #Para os fatores QUANTITATIVOS, regressao
-if(quali[i]==FALSE && an[i,5]<=sigF){
+if(quali[i]==FALSE && pvalor[i]<=sigF){
     cat(fac.names[i])
     reg.poly(resp, fatores[,i], an[9,1], an[9,2], an[i,1], an[i,2])
 }
 
-if(quali[i]==FALSE && an[i,5]>sigF) {
+if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
-    cat('\nAccording to the F test, the means of this factor are statistical equal.\n\n')
+    cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
 mean.table<-tapply.stat(resp,fatores[,i],mean)
 colnames(mean.table)<-c('Levels','Means')
 print(mean.table)
@@ -222,7 +230,7 @@ QMf1=SQf1/glf1
 Fcf1=QMf1/QME
 
 rn<-numeric(0)
-for(i in 1:nv2){ rn<-c(rn, paste(paste(fac.names[2],':',fac.names[1],sep=''),lf2[i]))}
+for(i in 1:nv2){ rn<-c(rn, paste(paste(fac.names[1],':',fac.names[2],sep=''),lf2[i]))}
 
 anavad1<-data.frame("DF"=c(glf1, glE),
 "SS"=c(round(c(SQf1,SQE),5)),
@@ -263,8 +271,11 @@ ii<-ii+1
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],an[9,1],an[9,2],sigT)
-                                        }
-                      }
+                                          }
+                        if(mcomp=='ccf'){
+                          ccf(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],an[9,1],an[9,2],sigT)
+                                          }
+                        }
     else{  #regressao
     cat('\n\n',fac.names[1],' inside of the level ',lf2[i],' of ',fac.names[2],'
 ------------------------------------------------------------------------')
@@ -273,6 +284,7 @@ ii<-ii+1
                               }
     else{cat('\n\n',fac.names[1],' inside of the level ',lf2[i],' of ',fac.names[2],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -307,7 +319,7 @@ QMf2=SQf2/glf2
 Fcf2=QMf2/QME
 
 rn<-numeric(0)
-for(k in 1:nv1){ rn<-c(rn, paste(paste(fac.names[1],':',fac.names[2],sep=''),lf1[k]))}
+for(k in 1:nv1){ rn<-c(rn, paste(paste(fac.names[2],':',fac.names[1],sep=''),lf1[k]))}
 
 anavad2<-data.frame("DF"=c(glf2, glE),
 "SS"=c(round(c(SQf2,SQE),5)),
@@ -348,8 +360,11 @@ ii<-ii+1
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],an[9,1],an[9,2],sigT)
-                                        }
-                      }
+                                          }
+                        if(mcomp=='ccf'){
+                          ccf(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],an[9,1],an[9,2],sigT)
+                                          }
+                        }
     else{  #regressao
         cat('\n\n',fac.names[2],' inside of the level ',lf1[i],' of ',fac.names[1],'
 ------------------------------------------------------------------------')
@@ -358,6 +373,7 @@ ii<-ii+1
                              }
     else{cat('\n\n',fac.names[2],' inside of the level ',lf1[i],' of ',fac.names[1],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -397,14 +413,15 @@ if(pvalor[5]>sigF && pvalor[6]>sigF) {
     if(mcomp=="ccboot"){
       ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
-#    if(mcomp=="ccf"){
-#      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
-#    }
+    if(mcomp=="ccf"){
+      ccf(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
   }
   
   if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
+    cat('------------------------------------------------------------------------\n')
     mean.table<-tapply.stat(resp,fatores[,i],mean)
     colnames(mean.table)<-c('Niveis','Medias')
     print(mean.table)
@@ -419,7 +436,8 @@ if(pvalor[5]>sigF && pvalor[6]>sigF) {
   
   if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
-    cat('\nAccording to the F test, the means of this factor are not different.\n\n')
+    cat('\nAccording to the F test, the means of this factor are not different.\n')
+    cat('------------------------------------------------------------------------\n')
     mean.table<-tapply.stat(resp,fatores[,i],mean)
     colnames(mean.table)<-c('Levels','Means')
     print(mean.table)
@@ -464,7 +482,7 @@ QMf3=SQf3/glf3
 Fcf3=QMf3/QME
 
 rn<-numeric(0)
-for(j in 1:nv3){ rn<-c(rn, paste(paste(fac.names[3],':',fac.names[1],sep=''),lf3[j]))}
+for(j in 1:nv3){ rn<-c(rn, paste(paste(fac.names[1],':',fac.names[3],sep=''),lf3[j]))}
 
 anavad3<-data.frame("DF"=c(glf3, glE),
 "SS"=c(round(c(SQf3,SQE),5)),
@@ -505,8 +523,11 @@ ii<-ii+1
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator3==lf3[i]],fatores[,1][Fator3==lf3[i]],an[9,1],an[9,2],sigT)
-                                        }
-                      }
+                                          }
+                        if(mcomp=='ccf'){
+                          ccf(resp[Fator3==lf3[i]],fatores[,1][Fator3==lf3[i]],an[9,1],an[9,2],sigT)
+                                          }
+                         }
     else{  #regressao
     cat('\n\n',fac.names[1],' inside of the level ',lf3[i],' of ',fac.names[3],'
 ------------------------------------------------------------------------')
@@ -515,6 +536,7 @@ ii<-ii+1
                               }
     else{cat('\n\n',fac.names[1],' inside of the level ',lf3[i],' of ',fac.names[3],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[Fator3==lf3[i]],fatores[,1][Fator3==lf3[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -549,7 +571,7 @@ QMf4=SQf4/glf4
 Fcf4=QMf4/QME
 
 rn<-numeric(0)
-for(k in 1:nv1){ rn<-c(rn, paste(paste(fac.names[1],':',fac.names[3],sep=''),lf1[k]))}
+for(k in 1:nv1){ rn<-c(rn, paste(paste(fac.names[3],':',fac.names[1],sep=''),lf1[k]))}
 
 anavad4<-data.frame("DF"=c(glf4, glE),
 "SS"=c(round(c(SQf4,SQE),5)),
@@ -590,8 +612,11 @@ ii<-ii+1
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator1==lf1[i]],fatores[,3][Fator1==lf1[i]],an[9,1],an[9,2],sigT)
-                                        }
-                      }
+                                          }
+                        if(mcomp=='ccf'){
+                          ccf(resp[Fator1==lf1[i]],fatores[,3][Fator1==lf1[i]],an[9,1],an[9,2],sigT)
+                                          }
+                        }
     else{  #regressao
         cat('\n\n',fac.names[3],' inside of the level ',lf1[i],' of ',fac.names[1],'
 ------------------------------------------------------------------------')
@@ -600,6 +625,7 @@ ii<-ii+1
                              }
     else{cat('\n\n',fac.names[3],' inside of the level ',lf1[i],' of ',fac.names[1],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[Fator1==lf1[i]],fatores[,3][Fator1==lf1[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -639,14 +665,15 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
     if(mcomp=="ccboot"){
       ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
-#    if(mcomp=="ccf"){
-#      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
-#    }
+    if(mcomp=="ccf"){
+      ccf(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
   }
   
   if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
+    cat('------------------------------------------------------------------------\n')
     mean.table<-tapply.stat(resp,fatores[,i],mean)
     colnames(mean.table)<-c('Niveis','Medias')
     print(mean.table)
@@ -661,7 +688,8 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
   
   if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
-    cat('\nAccording to the F test, the means of this factor are not different.\n\n')
+    cat('\nAccording to the F test, the means of this factor are not different.\n')
+    cat('------------------------------------------------------------------------\n')
     mean.table<-tapply.stat(resp,fatores[,i],mean)
     colnames(mean.table)<-c('Levels','Means')
     print(mean.table)
@@ -705,7 +733,7 @@ QMf5=SQf5/glf5
 Fcf5=QMf5/QME
 
 rn<-numeric(0)
-for(j in 1:nv3){ rn<-c(rn, paste(paste(fac.names[3],':',fac.names[2],sep=''),lf3[j]))}
+for(j in 1:nv3){ rn<-c(rn, paste(paste(fac.names[2],':',fac.names[3],sep=''),lf3[j]))}
 
 anavad5<-data.frame("DF"=c(glf5, glE),
 "SS"=c(round(c(SQf5,SQE),5)),
@@ -746,8 +774,11 @@ ii<-ii+1
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator3==lf3[i]],fatores[,2][Fator3==lf3[i]],an[9,1],an[9,2],sigT)
-                                        }
-                      }
+                                          }
+                        if(mcomp=='ccf'){
+                          ccf(resp[Fator3==lf3[i]],fatores[,2][Fator3==lf3[i]],an[9,1],an[9,2],sigT)
+                                          }
+                        }
     else{  #regressao
     cat('\n\n',fac.names[2],' inside of the level ',lf3[i],' of ',fac.names[3],'
 ------------------------------------------------------------------------')
@@ -756,6 +787,7 @@ ii<-ii+1
                               }
     else{cat('\n\n',fac.names[2],' inside of the level ',lf3[i],' of ',fac.names[3],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[Fator3==lf3[i]],fatores[,2][Fator3==lf3[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -790,7 +822,7 @@ QMf6=SQf6/glf6
 Fcf6=QMf6/QME
 
 rn<-numeric(0)
-for(i in 1:nv2){ rn<-c(rn, paste(paste(fac.names[2],':',fac.names[3],sep=''),lf2[i]))}
+for(i in 1:nv2){ rn<-c(rn, paste(paste(fac.names[3],':',fac.names[2],sep=''),lf2[i]))}
 
 anavad6<-data.frame("DF"=c(glf6, glE),
 "SS"=c(round(c(SQf6,SQE),5)),
@@ -831,8 +863,11 @@ ii<-ii+1
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator2==lf2[i]],fatores[,3][Fator2==lf2[i]],an[9,1],an[9,2],sigT)
-                                        }
-                      }
+                                          }
+                        if(mcomp=='ccf'){
+                          ccf(resp[Fator2==lf2[i]],fatores[,3][Fator2==lf2[i]],an[9,1],an[9,2],sigT)
+                                          }
+                        }
     else{  #regressao
         cat('\n\n',fac.names[3],' inside of the leve ',lf2[i],' of ',fac.names[2],'
 ------------------------------------------------------------------------')
@@ -841,6 +876,7 @@ ii<-ii+1
                              }
     else{cat('\n\n',fac.names[3],' inside of the leve ',lf2[i],' of ',fac.names[2],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[Fator2==lf2[i]],fatores[,3][Fator2==lf2[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -880,14 +916,15 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
     if(mcomp=="ccboot"){
       ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
-#    if(mcomp=="ccf"){
-#      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
-#    }
+    if(mcomp=="ccf"){
+      ccf(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
   }
   
   if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
+    cat('------------------------------------------------------------------------\n')
     mean.table<-tapply.stat(resp,fatores[,i],mean)
     colnames(mean.table)<-c('Niveis','Medias')
     print(mean.table)
@@ -902,7 +939,8 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
   
   if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
-    cat('\nAccording to the F test, the means of this factor are not different.\n\n')
+    cat('\nAccording to the F test, the means of this factor are not different.\n')
+    cat('------------------------------------------------------------------------\n')
     mean.table<-tapply.stat(resp,fatores[,i],mean)
     colnames(mean.table)<-c('Levels','Means')
     print(mean.table)
@@ -987,8 +1025,11 @@ ii<-0
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[fatores[,2]==lf2[i] & fatores[,3]==lf3[j]],fatores[,1][Fator2==lf2[i] & Fator3==lf3[j]],an[9,1],an[9,2],sigT)
+                                            }
+                        if(mcomp=='ccf'){
+                          ccf(resp[fatores[,2]==lf2[i] & fatores[,3]==lf3[j]],fatores[,1][Fator2==lf2[i] & Fator3==lf3[j]],an[9,1],an[9,2],sigT)
                                         }
-                      }
+                        }
     else{  #regressao
     cat('\n\n',fac.names[1],' inside of the combination of the levels ',lf2[i],' of ',fac.names[2],' and ',lf3[j],' of ',fac.names[3],'
 ------------------------------------------------------------------------')
@@ -998,6 +1039,7 @@ ii<-0
 
     else{cat('\n\n',fac.names[1],' inside of the combination of the levels ',lf2[i],' of ',fac.names[2],' and ',lf3[j],' of ',fac.names[3],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[fatores[,2]==lf2[i] & fatores[,3]==lf3[j]], fatores[,1][Fator2==lf2[i] & Fator3==lf3[j]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -1073,8 +1115,11 @@ for(k in 1:nv1) {
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[fatores[,1]==lf1[k] & fatores[,3]==lf3[j]],fatores[,2][Fator1==lf1[k] & fatores[,3]==lf3[j]],an[9,1],an[9,2],sigT)
-                                        }
-                      }
+                                           }
+                        if(mcomp=='ccf'){
+                          ccf(resp[fatores[,1]==lf1[k] & fatores[,3]==lf3[j]],fatores[,2][Fator1==lf1[k] & fatores[,3]==lf3[j]],an[9,1],an[9,2],sigT)
+                                          }
+                        }
     else{  #regressao
         cat('\n\n',fac.names[2],' inside of the combination of the levels ',lf1[k],' of ',fac.names[1],' and ',lf3[j],' of ',fac.names[3],'
 ------------------------------------------------------------------------')
@@ -1083,6 +1128,7 @@ for(k in 1:nv1) {
                              }
     else{cat('\n\n',fac.names[2],' inside of the combination of the levels ',lf1[k],' of ',fac.names[1],' and ',lf3[j],' of ',fac.names[3],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[fatores[,1]==lf1[k] & fatores[,3]==lf3[j]],fatores[,2][Fator1==lf1[k] & fatores[,3]==lf3[j]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -1155,7 +1201,10 @@ for(k in 1:nv1) {
                         if(mcomp=='ccboot'){
                           ccboot(resp[fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],fatores[,3][fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],an[9,1],an[9,2],sigT)
                                         }
-                      }
+                        if(mcomp=='ccf'){
+                          ccf(resp[fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],fatores[,3][fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],an[9,1],an[9,2],sigT)
+                                            }                
+                        }
     else{  #regressao
         cat('\n\n',fac.names[3],' inside of the combination of the levels ',lf1[k],' of ',fac.names[1],' and ',lf2[i],' of ',fac.names[2],'
 ------------------------------------------------------------------------')
@@ -1164,6 +1213,7 @@ for(k in 1:nv1) {
                              }
     else{cat('\n\n',fac.names[3],' inside of the combination of the levels ',lf1[k],' of ',fac.names[1],' and ',lf2[i],' of ',fac.names[2],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],fatores[,3][fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -1173,5 +1223,22 @@ for(k in 1:nv1) {
                 }
 
 }
-
+#Saida
+out<-list()
+out$residuals<-anava$residuals
+out$df.residual<-anava$df.residual
+out$coefficients<-anava$coefficients
+out$effects<-anava$effects
+out$fitted.values<-anava$fitted.values
+out$mean.Ad<-x
+out$means.factor1<-tapply.stat(resp,fatores[,1],mean)
+out$means.factor2<-tapply.stat(resp,fatores[,2],mean)
+out$means.factor3<-tapply.stat(resp,fatores[,3],mean)
+tabmedia<-model.tables(aov(resp~Fator1*Fator2*Fator3), "means")
+out$means.inside12<-tabmedia$tables$`Fator1:Fator2`
+out$means.inside13<-tabmedia$tables$`Fator1:Fator3`
+out$means.inside23<-tabmedia$tables$`Fator2:Fator3`
+out$means.inside123<-tabmedia$tables$`Fator1:Fator2:Fator3`
+#if(quali==FALSE && tab[[1]][1,5]<sigF) {out$reg<-reg}
+invisible(out)
 }
