@@ -88,12 +88,12 @@ Fcbc=QMbc/QME
 Fcabc=QMabc/QME
 Fcad=QMad/QME
 
-pv.fs=c(1-pf(Fca,gla,glE), 1-pf(Fcb,glb,glE), 1-pf(Fcb,glb,glE))
+pv.fs=c(1-pf(Fca,gla,glE), 1-pf(Fcb,glb,glE), 1-pf(Fcc,glc,glE))
 
 #Montando a tabela da ANAVA
 an<-data.frame("DF"=c(glB,gla, glb, glc, glab, glac, glbc, glabc, glad, glE, glT ),
 "SS"=c(round(c(SQB,SQa,SQb,SQc,SQab,SQac,SQbc,SQabc,SQad,SQE,SQT),5)),
-"MS"=c(round(c(QMB,QMa,QMb,QMc,QMab,QMac,QMbc,QMabc,QMad,QME,QMT),5)),
+"MS"=c(round(c(QMB,QMa,QMb,QMc,QMab,QMac,QMbc,QMabc,QMad,QME),5),''),
 "Fc"=c(round(c(FcB,Fca,Fcb,Fcc,Fcab,Fcac,Fcbc,Fcabc,Fcad),4),'',''),
 "Pr>Fc"=c(round(c(1-pf(FcB,glB,glE),pv.fs, 1-pf(Fcab,glab,glE), 1-pf(Fcac,glac,glE), 1-pf(Fcbc,glbc,glE), 1-pf(Fcabc,glabc,glE), 1-pf(Fcad,glad,glE)),4), ' ', ' '))
 colnames(an)[5]="Pr>Fc"
@@ -102,8 +102,11 @@ paste(fac.names[2],'*',fac.names[3],sep=''),paste(fac.names[1],'*',fac.names[2],
 cat('------------------------------------------------------------------------
 Analysis of Variance Table\n------------------------------------------------------------------------\n')
 print(an)
-cat('------------------------------------------------------------------------\n\n')
+cat('------------------------------------------------------------------------\n')
 pvalor<-c(1-pf(Fca,gla,glE), 1-pf(Fcb,glb,glE), 1-pf(Fcc,glc,glE), 1-pf(Fcab,glab,glE), 1-pf(Fcac,glac,glE), 1-pf(Fcbc,glbc,glE), 1-pf(Fcabc,glabc,glE))
+#CV
+cv<-round(sqrt(as.numeric(an[10,3]))/mean(col3)*100, 2)
+cat('CV =',cv,'%\n')
 
 #Teste de normalidade
 pvalor.shapiro<-shapiro.test(anava$residuals)$p.value
@@ -137,13 +140,13 @@ cat('------------------------------------------------------------------------\n'
 
 #Para nenhuma interacao significativa, fazer...
 if(1-pf(Fcab,glab,glE)>sigF && 1-pf(Fcac,glac,glE)>sigF && 1-pf(Fcbc,glbc,glE)>sigF && 1-pf(Fcabc,glabc,glE)>sigF) {
-cat('\nNot significant interaction: analyzing the simple effect
+cat('\nNo significant interaction: analyzing the simple effect
 ------------------------------------------------------------------------\n')
 fatores<-data.frame('fator 1'=factor1,'fator 2' = factor2,'fator 3' = factor3)
 
 for(i in 1:3){
 #Para os fatores QUALITATIVOS, teste de Tukey
-if(quali[i]==TRUE && an[i,5]<=sigF) {
+if(quali[i]==TRUE && pvalor[i]<=sigF) {
     cat(fac.names[i])
       if(mcomp=='tukey'){
     tukey(resp,fatores[,i],an[10,1],an[10,2],sigT)
@@ -166,10 +169,14 @@ if(quali[i]==TRUE && an[i,5]<=sigF) {
   if(mcomp=='ccboot'){
     ccboot(resp,fatores[,i],an[10,1],an[10,2],sigT)
                     }
+  if(mcomp=='ccf'){
+    ccf(resp,fatores[,i],an[10,1],an[10,2],sigT)
+                    }
                    }
-if(quali[i]==TRUE && an[i,5]>sigF) {
+if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
 mean.table<-tapply.stat(resp,fatores[,i],mean)
 colnames(mean.table)<-c('Levels','Means')
 print(mean.table)
@@ -177,14 +184,15 @@ cat('------------------------------------------------------------------------')
 }
 
 #Para os fatores QUANTITATIVOS, regressao
-if(quali[i]==FALSE && an[i,5]<=sigF){
+if(quali[i]==FALSE && pvalor[i]<=sigF){
     cat(fac.names[i])
     reg.poly(resp, fatores[,i], an[10,1], an[10,2], an[i,1], an[i,2])
 }
 
-if(quali[i]==FALSE && an[i,5]>sigF) {
+if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
-    cat('\nAccording to the F test, the means of this factor are statistical equal.\n\n')
+    cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
 mean.table<-tapply.stat(resp,fatores[,i],mean)
 colnames(mean.table)<-c('Levels','Means')
 print(mean.table)
@@ -228,7 +236,7 @@ QMf1=SQf1/glf1
 Fcf1=QMf1/QME
 
 rn<-numeric(0)
-for(i in 1:nv2){ rn<-c(rn, paste(paste(fac.names[2],':',fac.names[1],sep=''),lf2[i]))}
+for(i in 1:nv2){ rn<-c(rn, paste(paste(fac.names[1],':',fac.names[2],sep=''),lf2[i]))}
 
 anavad1<-data.frame("DF"=c(glf1, glE),
 "SS"=c(round(c(SQf1,SQE),5)),
@@ -269,8 +277,11 @@ ii<-ii+1
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],an[10,1],an[10,2],sigT)
-                                        }
-                      }
+                                          }
+                        if(mcomp=='ccf'){
+                          ccf(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],an[10,1],an[10,2],sigT)
+                                          }
+                        }
     else{  #regressao
     cat('\n\n',fac.names[1],' inside of the level ',lf2[i],' of ',fac.names[2],'
 ------------------------------------------------------------------------')
@@ -279,6 +290,7 @@ ii<-ii+1
                               }
     else{cat('\n\n',fac.names[1],' inside of the level ',lf2[i],' of ',fac.names[2],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -313,7 +325,7 @@ QMf2=SQf2/glf2
 Fcf2=QMf2/QME
 
 rn<-numeric(0)
-for(k in 1:nv1){ rn<-c(rn, paste(paste(fac.names[1],':',fac.names[2],sep=''),lf1[k]))}
+for(k in 1:nv1){ rn<-c(rn, paste(paste(fac.names[2],':',fac.names[1],sep=''),lf1[k]))}
 
 anavad2<-data.frame("DF"=c(glf2, glE),
 "SS"=c(round(c(SQf2,SQE),5)),
@@ -354,7 +366,10 @@ ii<-ii+1
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],an[10,1],an[10,2],sigT)
-                                        }
+                                          }
+                        if(mcomp=='ccf'){
+                          ccf(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],an[10,1],an[10,2],sigT)
+                                          }
                       }
     else{  #regressao
         cat('\n\n',fac.names[2],' inside of the level ',lf1[i],' of ',fac.names[1],'
@@ -364,6 +379,7 @@ ii<-ii+1
                              }
     else{cat('\n\n',fac.names[2],' inside of the level ',lf1[i],' of ',fac.names[1],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -403,14 +419,15 @@ if(pvalor[5]>sigF && pvalor[6]>sigF) {
     if(mcomp=="ccboot"){
       ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
-#    if(mcomp=="ccf"){
-#      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
-#    }
+    if(mcomp=="ccf"){
+      ccf(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
   }
   
   if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
+    cat('------------------------------------------------------------------------\n')
     mean.table<-tapply.stat(resp,fatores[,i],mean)
     colnames(mean.table)<-c('Niveis','Medias')
     print(mean.table)
@@ -425,7 +442,8 @@ if(pvalor[5]>sigF && pvalor[6]>sigF) {
   
   if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
-    cat('\nAccording to the F test, the means of this factor are not different.\n\n')
+    cat('\nAccording to the F test, the means of this factor are not different.\n')
+    cat('------------------------------------------------------------------------\n')
     mean.table<-tapply.stat(resp,fatores[,i],mean)
     colnames(mean.table)<-c('Levels','Means')
     print(mean.table)
@@ -469,7 +487,7 @@ QMf3=SQf3/glf3
 Fcf3=QMf3/QME
 
 rn<-numeric(0)
-for(j in 1:nv3){ rn<-c(rn, paste(paste(fac.names[3],':',fac.names[1],sep=''),lf3[j]))}
+for(j in 1:nv3){ rn<-c(rn, paste(paste(fac.names[1],':',fac.names[3],sep=''),lf3[j]))}
 
 anavad3<-data.frame("DF"=c(glf3, glE),
 "SS"=c(round(c(SQf3,SQE),5)),
@@ -510,8 +528,11 @@ ii<-ii+1
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator3==lf3[i]],fatores[,1][Fator3==lf3[i]],an[10,1],an[10,2],sigT)
-                                        }
-                      }
+                                          }
+                        if(mcomp=='ccf'){
+                          ccf(resp[Fator3==lf3[i]],fatores[,1][Fator3==lf3[i]],an[10,1],an[10,2],sigT)
+                                          }
+                        }
     else{  #regressao
     cat('\n\n',fac.names[1],' inside of the level ',lf3[i],' of ',fac.names[3],'
 ------------------------------------------------------------------------')
@@ -520,6 +541,7 @@ ii<-ii+1
                               }
     else{cat('\n\n',fac.names[1],' inside of the level ',lf3[i],' of ',fac.names[3],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[Fator3==lf3[i]],fatores[,1][Fator3==lf3[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -554,7 +576,7 @@ QMf4=SQf4/glf4
 Fcf4=QMf4/QME
 
 rn<-numeric(0)
-for(k in 1:nv1){ rn<-c(rn, paste(paste(fac.names[1],':',fac.names[3],sep=''),lf1[k]))}
+for(k in 1:nv1){ rn<-c(rn, paste(paste(fac.names[3],':',fac.names[1],sep=''),lf1[k]))}
 
 anavad4<-data.frame("DF"=c(glf4, glE),
 "SS"=c(round(c(SQf4,SQE),5)),
@@ -596,6 +618,9 @@ ii<-ii+1
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator1==lf1[i]],fatores[,3][Fator1==lf1[i]],an[10,1],an[10,2],sigT)
                                         }
+                        if(mcomp=='ccf'){
+                          ccf(resp[Fator1==lf1[i]],fatores[,3][Fator1==lf1[i]],an[10,1],an[10,2],sigT)
+                                        }
                       }
     else{  #regressao
         cat('\n\n',fac.names[3],' inside of the level ',lf1[i],' of ',fac.names[1],'
@@ -605,6 +630,7 @@ ii<-ii+1
                              }
     else{cat('\n\n',fac.names[3],' inside of the level ',lf1[i],' of ',fac.names[1],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[Fator1==lf1[i]],fatores[,3][Fator1==lf1[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -644,14 +670,15 @@ if(pvalor[4]>sigF && pvalor[6]>sigF) {
     if(mcomp=="ccboot"){
       ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
-#    if(mcomp=="ccf"){
-#      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
-#    }
+    if(mcomp=="ccf"){
+      ccf(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
   }
   
   if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
+    cat('------------------------------------------------------------------------\n')
     mean.table<-tapply.stat(resp,fatores[,i],mean)
     colnames(mean.table)<-c('Niveis','Medias')
     print(mean.table)
@@ -666,7 +693,8 @@ if(pvalor[4]>sigF && pvalor[6]>sigF) {
   
   if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
-    cat('\nAccording to the F test, the means of this factor are not different.\n\n')
+    cat('\nAccording to the F test, the means of this factor are not different.\n')
+    cat('------------------------------------------------------------------------\n')
     mean.table<-tapply.stat(resp,fatores[,i],mean)
     colnames(mean.table)<-c('Levels','Means')
     print(mean.table)
@@ -711,7 +739,7 @@ QMf5=SQf5/glf5
 Fcf5=QMf5/QME
 
 rn<-numeric(0)
-for(j in 1:nv3){ rn<-c(rn, paste(paste(fac.names[3],':',fac.names[2],sep=''),lf3[j]))}
+for(j in 1:nv3){ rn<-c(rn, paste(paste(fac.names[2],':',fac.names[3],sep=''),lf3[j]))}
 
 anavad5<-data.frame("DF"=c(glf5, glE),
 "SS"=c(round(c(SQf5,SQE),5)),
@@ -752,8 +780,11 @@ ii<-ii+1
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator3==lf3[i]],fatores[,2][Fator3==lf3[i]],an[10,1],an[10,2],sigT)
-                                        }
-                      }
+                                           }
+                        if(mcomp=='ccf'){
+                          ccf(resp[Fator3==lf3[i]],fatores[,2][Fator3==lf3[i]],an[10,1],an[10,2],sigT)
+                                          }
+                        }
     else{  #regressao
     cat('\n\n',fac.names[2],' inside of the level ',lf3[i],' of ',fac.names[3],'
 ------------------------------------------------------------------------')
@@ -762,6 +793,7 @@ ii<-ii+1
                               }
     else{cat('\n\n',fac.names[2],' inside of the level ',lf3[i],' of ',fac.names[3],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[Fator3==lf3[i]],fatores[,2][Fator3==lf3[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -796,7 +828,7 @@ QMf6=SQf6/glf6
 Fcf6=QMf6/QME
 
 rn<-numeric(0)
-for(i in 1:nv2){ rn<-c(rn, paste(paste(fac.names[2],':',fac.names[3],sep=''),lf2[i]))}
+for(i in 1:nv2){ rn<-c(rn, paste(paste(fac.names[3],':',fac.names[2],sep=''),lf2[i]))}
 
 anavad6<-data.frame("DF"=c(glf6, glE),
 "SS"=c(round(c(SQf6,SQE),5)),
@@ -837,8 +869,11 @@ ii<-ii+1
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator2==lf2[i]],fatores[,3][Fator2==lf2[i]],an[10,1],an[10,2],sigT)
-                                        }
-                      }
+                                          }
+                        if(mcomp=='ccf'){
+                          ccf(resp[Fator2==lf2[i]],fatores[,3][Fator2==lf2[i]],an[10,1],an[10,2],sigT)
+                                          }
+                        }
     else{  #regressao
         cat('\n\n',fac.names[3],' inside of the leve ',lf2[i],' of ',fac.names[2],'
 ------------------------------------------------------------------------')
@@ -847,6 +882,7 @@ ii<-ii+1
                              }
     else{cat('\n\n',fac.names[3],' inside of the leve ',lf2[i],' of ',fac.names[2],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[Fator2==lf2[i]],fatores[,3][Fator2==lf2[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -886,14 +922,15 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
     if(mcomp=="ccboot"){
       ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
-#    if(mcomp=="ccf"){
-#      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
-#    }
+    if(mcomp=="ccf"){
+      ccf(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
   }
   
   if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
+    cat('------------------------------------------------------------------------\n')
     mean.table<-tapply.stat(resp,fatores[,i],mean)
     colnames(mean.table)<-c('Niveis','Medias')
     print(mean.table)
@@ -908,7 +945,8 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
   
   if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
-    cat('\nAccording to the F test, the means of this factor are not different.\n\n')
+    cat('\nAccording to the F test, the means of this factor are not different.\n')
+    cat('------------------------------------------------------------------------\n')
     mean.table<-tapply.stat(resp,fatores[,i],mean)
     colnames(mean.table)<-c('Levels','Means')
     print(mean.table)
@@ -994,8 +1032,11 @@ ii<-0
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[fatores[,2]==lf2[i] & fatores[,3]==lf3[j]],fatores[,1][Fator2==lf2[i] & Fator3==lf3[j]],an[10,1],an[10,2],sigT)
-                                        }
-                      }
+                                          }
+                        if(mcomp=='ccf'){
+                          ccf(resp[fatores[,2]==lf2[i] & fatores[,3]==lf3[j]],fatores[,1][Fator2==lf2[i] & Fator3==lf3[j]],an[10,1],an[10,2],sigT)
+                                          }
+                        }
     else{  #regressao
     cat('\n\n',fac.names[1],' inside of the combination of the levels ',lf2[i],' of ',fac.names[2],' and ',lf3[j],' of ',fac.names[3],'
 ------------------------------------------------------------------------')
@@ -1005,6 +1046,7 @@ ii<-0
 
     else{cat('\n\n',fac.names[1],' inside of the combination of the levels ',lf2[i],' of ',fac.names[2],' and ',lf3[j],' of ',fac.names[3],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[fatores[,2]==lf2[i] & fatores[,3]==lf3[j]], fatores[,1][Fator2==lf2[i] & Fator3==lf3[j]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -1080,8 +1122,11 @@ for(k in 1:nv1) {
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[fatores[,1]==lf1[k] & fatores[,3]==lf3[j]],fatores[,2][Fator1==lf1[k] & fatores[,3]==lf3[j]],an[10,1],an[10,2],sigT)
-                                        }
-                      }
+                                            }
+                        if(mcomp=='ccf'){
+                          ccf(resp[fatores[,1]==lf1[k] & fatores[,3]==lf3[j]],fatores[,2][Fator1==lf1[k] & fatores[,3]==lf3[j]],an[10,1],an[10,2],sigT)
+                                          }
+                        }
     else{  #regressao
         cat('\n\n',fac.names[2],' inside of the combination of the levels ',lf1[k],' of ',fac.names[1],' and ',lf3[j],' of ',fac.names[3],'
 ------------------------------------------------------------------------')
@@ -1090,6 +1135,7 @@ for(k in 1:nv1) {
                              }
     else{cat('\n\n',fac.names[2],' inside of the combination of the levels ',lf1[k],' of ',fac.names[1],' and ',lf3[j],' of ',fac.names[3],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[fatores[,1]==lf1[k] & fatores[,3]==lf3[j]],fatores[,2][Fator1==lf1[k] & fatores[,3]==lf3[j]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -1161,8 +1207,11 @@ for(k in 1:nv1) {
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],fatores[,3][fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],an[10,1],an[10,2],sigT)
-                                        }
-                      }
+                                           }
+                        if(mcomp=='ccf'){
+                          ccf(resp[fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],fatores[,3][fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],an[10,1],an[10,2],sigT)
+                                          }
+                        }
     else{  #regressao
         cat('\n\n',fac.names[3],' inside of the combination of the levels ',lf1[k],' of ',fac.names[1],' and ',lf2[i],' of ',fac.names[2],'
 ------------------------------------------------------------------------')
@@ -1171,6 +1220,7 @@ for(k in 1:nv1) {
                              }
     else{cat('\n\n',fac.names[3],' inside of the combination of the levels ',lf1[k],' of ',fac.names[1],' and ',lf2[i],' of ',fac.names[2],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],fatores[,3][fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -1180,5 +1230,22 @@ for(k in 1:nv1) {
                 }
 
 }
-
+#Saida
+out<-list()
+out$residuals<-anava$residuals
+out$df.residual<-anava$df.residual
+out$coefficients<-anava$coefficients
+out$effects<-anava$effects
+out$fitted.values<-anava$fitted.values
+out$mean.Ad<-x
+out$means.factor1<-tapply.stat(resp,fatores[,1],mean)
+out$means.factor2<-tapply.stat(resp,fatores[,2],mean)
+out$means.factor3<-tapply.stat(resp,fatores[,3],mean)
+tabmedia<-model.tables(aov(resp~Block+Fator1*Fator2*Fator3), "means")
+out$means.inside12<-tabmedia$tables$`Fator1:Fator2`
+out$means.inside13<-tabmedia$tables$`Fator1:Fator3`
+out$means.inside23<-tabmedia$tables$`Fator2:Fator3`
+out$means.inside123<-tabmedia$tables$`Fator1:Fator2:Fator3`
+#if(quali==FALSE && tab[[1]][1,5]<sigF) {out$reg<-reg}
+invisible(out)
 }
