@@ -16,7 +16,6 @@ nv2<-length(summary(Fator2))   #Diz quantos niveis tem o fator 2.
 nv3<-length(summary(Fator3))   #Diz quantos niveis tem o fator 3.
 J<-(length(resp))/(nv1*nv2*nv3)
 
-
 lf1<-levels(Fator1)
 lf2<-levels(Fator2)
 lf3<-levels(Fator3)
@@ -71,7 +70,7 @@ pv.fs=c(1-pf(Fca,gla,glE),1-pf(Fcb,glb,glE),1-pf(Fcc,glc,glE))
 #Montando a tabela da ANAVA
 an<-data.frame("DF"=c(glB,gla, glb, glc, glab, glac, glbc, glabc, glE, glT ),
 "SS"=c(round(c(SQB,SQa,SQb,SQc,SQab,SQac,SQbc,SQabc,SQE,SQT),5)),
-"MS"=c(round(c(QMB,QMa,QMb,QMc,QMab,QMac,QMbc,QMabc,QME,QMT),5)),
+"MS"=c(round(c(QMB,QMa,QMb,QMc,QMab,QMac,QMbc,QMabc,QME),5),''),
 "Fc"=c(round(c(FcB,Fca,Fcb,Fcc,Fcab,Fcac,Fcbc,Fcabc),4),'',''),
 "Pr>Fc"=c(round(c(1-pf(FcB,glB,glE),pv.fs, 1-pf(Fcab,glab,glE), 1-pf(Fcac,glac,glE),
 1-pf(Fcbc,glbc,glE), 1-pf(Fcabc,glabc,glE)),4), ' ', ' '))
@@ -81,8 +80,11 @@ paste(fac.names[2],'*',fac.names[3],sep=''),paste(fac.names[1],'*',fac.names[2],
 cat('------------------------------------------------------------------------
 Analysis of Variance Table\n------------------------------------------------------------------------\n')
 print(an)   
-cat('------------------------------------------------------------------------\n\n')
+cat('------------------------------------------------------------------------\n')
 pvalor<-c(1-pf(Fca,gla,glE), 1-pf(Fcb,glb,glE), 1-pf(Fcc,glc,glE), 1-pf(Fcab,glab,glE), 1-pf(Fcac,glac,glE), 1-pf(Fcbc,glbc,glE), 1-pf(Fcabc,glabc,glE))
+#CV
+cv<-round(sqrt(as.numeric(an[9,3]))/mean(resp)*100, 2)
+cat('CV =',cv,'%\n')
 
 #Teste de normalidade
 pvalor.shapiro<-shapiro.test(anava$residuals)$p.value
@@ -95,7 +97,7 @@ if(pvalor.shapiro>0.05){cat('According to Shapiro-Wilk normality test at 5% of s
 
 #Para nenhuma interacao significativa, fazer...
 if(1-pf(Fcab,glab,glE)>sigF && 1-pf(Fcac,glac,glE)>sigF && 1-pf(Fcbc,glbc,glE)>sigF && 1-pf(Fcabc,glabc,glE)>sigF) {
-cat('\nNot significant interaction: analyzing the simple effect
+cat('\nNo significant interaction: analyzing the simple effect
 ------------------------------------------------------------------------\n')
 fatores<-data.frame('fator 1'=factor1,'fator 2' = factor2,'fator 3' = factor3)
 
@@ -124,10 +126,14 @@ if(quali[i]==TRUE && pv.fs[i]<=sigF) {
   if(mcomp=='ccboot'){
     ccboot(resp,fatores[,i],an[9,1],an[9,2],sigT)
                     }
-                   }
+  if(mcomp=='ccf'){
+    ccf(resp,fatores[,i],an[9,1],an[9,2],sigT)
+                  }
+     }
 if(quali[i]==TRUE && pv.fs[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
 mean.table<-tapply.stat(resp,fatores[,i],mean)
 colnames(mean.table)<-c('Levels','Means')
 print(mean.table)
@@ -142,7 +148,8 @@ if(quali[i]==FALSE && pv.fs[i]<=sigF){
 
 if(quali[i]==FALSE && pv.fs[i]>sigF) {
     cat(fac.names[i])
-    cat('\nAccording to the F test, the means of this factor are statistical equal.\n\n')
+    cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
 mean.table<-tapply.stat(resp,fatores[,i],mean)
 colnames(mean.table)<-c('Levels','Means')
 print(mean.table)
@@ -186,7 +193,7 @@ QMf1=SQf1/glf1
 Fcf1=QMf1/QME
 
 rn<-numeric(0)
-for(i in 1:nv2){ rn<-c(rn, paste(paste(fac.names[2],':',fac.names[1],sep=''),lf2[i]))}
+for(i in 1:nv2){ rn<-c(rn, paste(paste(fac.names[1],':',fac.names[2],sep=''),lf2[i]))}
 
 anavad1<-data.frame("DF"=c(glf1, glE),
 "SS"=c(round(c(SQf1,SQE),5)),
@@ -227,7 +234,10 @@ ii<-ii+1
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],an[9,1],an[9,2],sigT)
-                                        }
+                                          }
+                        if(mcomp=='ccf'){
+                          ccf(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],an[9,1],an[9,2],sigT)
+                                          }
                       }
     else{  #regressao
     cat('\n\n',fac.names[1],' inside of the level ',lf2[i],' of ',fac.names[2],'
@@ -237,6 +247,7 @@ ii<-ii+1
                               }
     else{cat('\n\n',fac.names[1],' inside of the level ',lf2[i],' of ',fac.names[2],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -271,7 +282,7 @@ QMf2=SQf2/glf2
 Fcf2=QMf2/QME
 
 rn<-numeric(0)
-for(k in 1:nv1){ rn<-c(rn, paste(paste(fac.names[1],':',fac.names[2],sep=''),lf1[k]))}
+for(k in 1:nv1){ rn<-c(rn, paste(paste(fac.names[2],':',fac.names[1],sep=''),lf1[k]))}
 
 anavad2<-data.frame("DF"=c(glf2, glE),
 "SS"=c(round(c(SQf2,SQE),5)),
@@ -312,7 +323,10 @@ ii<-ii+1
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],an[9,1],an[9,2],sigT)
-                                        }
+                                          }
+                        if(mcomp=='ccf'){
+                          ccf(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],an[9,1],an[9,2],sigT)
+                                          }
                       }
     else{  #regressao
         cat('\n\n',fac.names[2],' inside of the level ',lf1[i],' of ',fac.names[1],'
@@ -322,6 +336,7 @@ ii<-ii+1
                              }
     else{cat('\n\n',fac.names[2],' inside of the level ',lf1[i],' of ',fac.names[1],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -361,14 +376,15 @@ if(pvalor[5]>sigF && pvalor[6]>sigF) {
     if(mcomp=="ccboot"){
       ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
-#    if(mcomp=="ccf"){
-#      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
-#    }
+    if(mcomp=="ccf"){
+      ccf(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
   }
   
   if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
+    cat('------------------------------------------------------------------------\n')
     mean.table<-tapply.stat(resp,fatores[,i],mean)
     colnames(mean.table)<-c('Niveis','Medias')
     print(mean.table)
@@ -384,6 +400,7 @@ if(pvalor[5]>sigF && pvalor[6]>sigF) {
   if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n\n')
+    cat('------------------------------------------------------------------------\n')
     mean.table<-tapply.stat(resp,fatores[,i],mean)
     colnames(mean.table)<-c('Levels','Means')
     print(mean.table)
@@ -427,7 +444,7 @@ QMf3=SQf3/glf3
 Fcf3=QMf3/QME
 
 rn<-numeric(0)
-for(j in 1:nv3){ rn<-c(rn, paste(paste(fac.names[3],':',fac.names[1],sep=''),lf3[j]))}
+for(j in 1:nv3){ rn<-c(rn, paste(paste(fac.names[1],':',fac.names[3],sep=''),lf3[j]))}
 
 anavad3<-data.frame("DF"=c(glf3, glE),
 "SS"=c(round(c(SQf3,SQE),5)),
@@ -468,7 +485,10 @@ ii<-ii+1
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator3==lf3[i]],fatores[,1][Fator3==lf3[i]],an[9,1],an[9,2],sigT)
-                                        }
+                                          }
+                        if(mcomp=='ccf'){
+                          ccf(resp[Fator3==lf3[i]],fatores[,1][Fator3==lf3[i]],an[9,1],an[9,2],sigT)
+                                          }
                       }
     else{  #regressao
     cat('\n\n',fac.names[1],' inside of the level ',lf3[i],' of ',fac.names[3],'
@@ -478,6 +498,7 @@ ii<-ii+1
                               }
     else{cat('\n\n',fac.names[1],' inside of the level ',lf3[i],' of ',fac.names[3],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[Fator3==lf3[i]],fatores[,1][Fator3==lf3[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -512,7 +533,7 @@ QMf4=SQf4/glf4
 Fcf4=QMf4/QME
 
 rn<-numeric(0)
-for(k in 1:nv1){ rn<-c(rn, paste(paste(fac.names[1],':',fac.names[3],sep=''),lf1[k]))}
+for(k in 1:nv1){ rn<-c(rn, paste(paste(fac.names[3],':',fac.names[1],sep=''),lf1[k]))}
 
 anavad4<-data.frame("DF"=c(glf4, glE),
 "SS"=c(round(c(SQf4,SQE),5)),
@@ -554,7 +575,10 @@ ii<-ii+1
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator1==lf1[i]],fatores[,3][Fator1==lf1[i]],an[9,1],an[9,2],sigT)
                                         }
-                      }
+                        if(mcomp=='ccf'){
+                          ccf(resp[Fator1==lf1[i]],fatores[,3][Fator1==lf1[i]],an[9,1],an[9,2],sigT)
+                                          }                
+                        }
     else{  #regressao
         cat('\n\n',fac.names[3],' inside of the level ',lf1[i],' of ',fac.names[1],'
 ------------------------------------------------------------------------')
@@ -563,6 +587,7 @@ ii<-ii+1
                              }
     else{cat('\n\n',fac.names[3],' inside of the level ',lf1[i],' of ',fac.names[1],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[Fator1==lf1[i]],fatores[,3][Fator1==lf1[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -602,14 +627,15 @@ if(pvalor[4]>sigF && pvalor[6]>sigF) {
     if(mcomp=="ccboot"){
       ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
-#    if(mcomp=="ccf"){
-#      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
-#    }
+    if(mcomp=="ccf"){
+      ccf(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
   }
   
   if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
+    cat('------------------------------------------------------------------------\n')
     mean.table<-tapply.stat(resp,fatores[,i],mean)
     colnames(mean.table)<-c('Niveis','Medias')
     print(mean.table)
@@ -624,7 +650,8 @@ if(pvalor[4]>sigF && pvalor[6]>sigF) {
   
   if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
-    cat('\nAccording to the F test, the means of this factor are not different.\n\n')
+    cat('\nAccording to the F test, the means of this factor are not different.\n')
+    cat('------------------------------------------------------------------------\n')
     mean.table<-tapply.stat(resp,fatores[,i],mean)
     colnames(mean.table)<-c('Levels','Means')
     print(mean.table)
@@ -668,7 +695,7 @@ QMf5=SQf5/glf5
 Fcf5=QMf5/QME
 
 rn<-numeric(0)
-for(j in 1:nv3){ rn<-c(rn, paste(paste(fac.names[3],':',fac.names[2],sep=''),lf3[j]))}
+for(j in 1:nv3){ rn<-c(rn, paste(paste(fac.names[2],':',fac.names[3],sep=''),lf3[j]))}
 
 anavad5<-data.frame("DF"=c(glf5, glE),
 "SS"=c(round(c(SQf5,SQE),5)),
@@ -709,8 +736,11 @@ ii<-ii+1
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator3==lf3[i]],fatores[,2][Fator3==lf3[i]],an[9,1],an[9,2],sigT)
-                                        }
-                      }
+                                          }
+                        if(mcomp=='ccf'){
+                          ccf(resp[Fator3==lf3[i]],fatores[,2][Fator3==lf3[i]],an[9,1],an[9,2],sigT)
+                                          }
+                        }
     else{  #regressao
     cat('\n\n',fac.names[2],' inside of the level ',lf3[i],' of ',fac.names[3],'
 ------------------------------------------------------------------------')
@@ -719,6 +749,7 @@ ii<-ii+1
                               }
     else{cat('\n\n',fac.names[2],' inside of the level ',lf3[i],' of ',fac.names[3],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[Fator3==lf3[i]],fatores[,2][Fator3==lf3[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -753,7 +784,7 @@ QMf6=SQf6/glf6
 Fcf6=QMf6/QME
 
 rn<-numeric(0)
-for(i in 1:nv2){ rn<-c(rn, paste(paste(fac.names[2],':',fac.names[3],sep=''),lf2[i]))}
+for(i in 1:nv2){ rn<-c(rn, paste(paste(fac.names[3],':',fac.names[2],sep=''),lf2[i]))}
 
 anavad6<-data.frame("DF"=c(glf6, glE),
 "SS"=c(round(c(SQf6,SQE),5)),
@@ -795,7 +826,10 @@ ii<-ii+1
                         if(mcomp=='ccboot'){
                           ccboot(resp[Fator2==lf2[i]],fatores[,3][Fator2==lf2[i]],an[9,1],an[9,2],sigT)
                                         }
-                      }
+                        if(mcomp=='ccf'){
+                          ccf(resp[Fator2==lf2[i]],fatores[,3][Fator2==lf2[i]],an[9,1],an[9,2],sigT)
+                                          }                
+                        }
     else{  #regressao
         cat('\n\n',fac.names[3],' inside of the leve ',lf2[i],' of ',fac.names[2],'
 ------------------------------------------------------------------------')
@@ -804,6 +838,7 @@ ii<-ii+1
                              }
     else{cat('\n\n',fac.names[3],' inside of the leve ',lf2[i],' of ',fac.names[2],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[Fator2==lf2[i]],fatores[,3][Fator2==lf2[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -843,14 +878,15 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
     if(mcomp=="ccboot"){
       ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
-#    if(mcomp=="ccf"){
-#      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
-#    }
+    if(mcomp=="ccf"){
+      ccf(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    }
   }
   
   if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nAccording to the F test, the means of this factor are not different.\n')
+    cat('------------------------------------------------------------------------\n')
     mean.table<-tapply.stat(resp,fatores[,i],mean)
     colnames(mean.table)<-c('Niveis','Medias')
     print(mean.table)
@@ -865,7 +901,8 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
   
   if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
-    cat('\nAccording to the F test, the means of this factor are not different.\n\n')
+    cat('\nAccording to the F test, the means of this factor are not different.\n')
+    cat('------------------------------------------------------------------------\n')
     mean.table<-tapply.stat(resp,fatores[,i],mean)
     colnames(mean.table)<-c('Levels','Means')
     print(mean.table)
@@ -954,7 +991,10 @@ ii<-0
                         if(mcomp=='ccboot'){
                           ccboot(resp[fatores[,2]==lf2[i] & fatores[,3]==lf3[j]],fatores[,1][Fator2==lf2[i] & Fator3==lf3[j]],an[9,1],an[9,2],sigT)
                                         }
-                      }
+                        if(mcomp=='ccf'){
+                          ccf(resp[fatores[,2]==lf2[i] & fatores[,3]==lf3[j]],fatores[,1][Fator2==lf2[i] & Fator3==lf3[j]],an[9,1],an[9,2],sigT)
+                                          }            
+                        }
     else{  #regressao
     cat('\n\n',fac.names[1],' inside of the combination of the levels ',lf2[i],' of ',fac.names[2],' and ',lf3[j],' of ',fac.names[3],'
 ------------------------------------------------------------------------')
@@ -964,6 +1004,7 @@ ii<-0
 
     else{cat('\n\n',fac.names[1],' inside of the combination of the levels ',lf2[i],' of ',fac.names[2],' and ',lf3[j],' of ',fac.names[3],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[fatores[,2]==lf2[i] & fatores[,3]==lf3[j]], fatores[,1][Fator2==lf2[i] & Fator3==lf3[j]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -1039,8 +1080,11 @@ for(k in 1:nv1) {
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[fatores[,1]==lf1[k] & fatores[,3]==lf3[j]],fatores[,2][Fator1==lf1[k] & fatores[,3]==lf3[j]],an[9,1],an[9,2],sigT)
-                                        }
-                      }
+                                          }
+                        if(mcomp=='ccf'){
+                          ccf(resp[fatores[,1]==lf1[k] & fatores[,3]==lf3[j]],fatores[,2][Fator1==lf1[k] & fatores[,3]==lf3[j]],an[9,1],an[9,2],sigT)
+                                          }
+                        }
     else{  #regressao
         cat('\n\n',fac.names[2],' inside of the combination of the levels ',lf1[k],' of ',fac.names[1],' and ',lf3[j],' of ',fac.names[3],'
 ------------------------------------------------------------------------')
@@ -1049,6 +1093,7 @@ for(k in 1:nv1) {
                              }
     else{cat('\n\n',fac.names[2],' inside of the combination of the levels ',lf1[k],' of ',fac.names[1],' and ',lf3[j],' of ',fac.names[3],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[fatores[,1]==lf1[k] & fatores[,3]==lf3[j]],fatores[,2][Fator1==lf1[k] & fatores[,3]==lf3[j]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -1120,8 +1165,11 @@ for(k in 1:nv1) {
                                         }
                         if(mcomp=='ccboot'){
                           ccboot(resp[fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],fatores[,3][fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],an[9,1],an[9,2],sigT)
-                                        }
-                      }
+                                          }
+                        if(mcomp=='ccf'){
+                          ccf(resp[fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],fatores[,3][fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],an[9,1],an[9,2],sigT)
+                                            }
+                        }
     else{  #regressao
         cat('\n\n',fac.names[3],' inside of the combination of the levels ',lf1[k],' of ',fac.names[1],' and ',lf2[i],' of ',fac.names[2],'
 ------------------------------------------------------------------------')
@@ -1130,6 +1178,7 @@ for(k in 1:nv1) {
                              }
     else{cat('\n\n',fac.names[3],' inside of the combination of the levels ',lf1[k],' of ',fac.names[1],' and ',lf2[i],' of ',fac.names[2],'\n')
     cat('\nAccording to the F test, the means of this factor are statistical equal.\n')
+    cat('------------------------------------------------------------------------\n')
         mean.table<-tapply.stat(resp[fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],fatores[,3][fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],mean)
         colnames(mean.table)<-c('  Levels','    Means')
         print(mean.table)
@@ -1139,5 +1188,21 @@ for(k in 1:nv1) {
                 }
 
 }
-
+#Saida
+out<-list()
+out$residuals<-anava$residuals
+out$df.residual<-anava$df.residual
+out$coefficients<-anava$coefficients
+out$effects<-anava$effects
+out$fitted.values<-anava$fitted.values
+out$means.factor1<-tapply.stat(resp,fatores[,1],mean)
+out$means.factor2<-tapply.stat(resp,fatores[,2],mean)
+out$means.factor3<-tapply.stat(resp,fatores[,3],mean)
+tabmedia<-model.tables(anava, "means")
+out$means.inside12<-tabmedia$tables$`Fator1:Fator2`
+out$means.inside13<-tabmedia$tables$`Fator1:Fator3`
+out$means.inside23<-tabmedia$tables$`Fator2:Fator3`
+out$means.inside123<-tabmedia$tables$`Fator1:Fator2:Fator3`
+#if(quali==FALSE && tab[[1]][1,5]<sigF) {out$reg<-reg}
+invisible(out)
 }
